@@ -38,12 +38,15 @@ from ajsonapi.relationships import (
     OneToOneLocalRelationship,
     OneToOneRemoteRelationship,
 )
+from ajsonapi.types import Boolean  # deprecating
+from ajsonapi.types import DateTimeTimeZone  # deprecating
 from ajsonapi.types import (
-    Boolean,
+    Bool,
     DateTime,
-    DateTimeTimeZone,
+    DateTimeTZ,
     Float32,
     Float64,
+    Int16,
     Int32,
     Int64,
     Json,
@@ -54,4 +57,4 @@ assert version_info >= (3, 7), 'Need Python 3.7+ for module ajsonapi'
 del version_info
 
 __docformat__ = 'restructuredtext'
-__version__ = '0.6.3'
+__version__ = '0.6.6'
