@@ -29,6 +29,7 @@ from asyncpg.exceptions import (
 )
 from asyncpg.pool import create_pool
 
+from ajsonapi.events import Event
 from ajsonapi.exceptions import ErrorsException
 from ajsonapi.init import init
 from ajsonapi.requests import (
@@ -53,6 +54,7 @@ class Application:
     """
 
     def __init__(self, *args, **kwargs):
+        Event.connect(self)
         self.app = web.Application(*args, **kwargs)
         self.ws_list = []
         self.pool = None
@@ -91,7 +93,7 @@ class Application:
     async def create_tables(self):
         """Creates all tables in the database."""
         # pylint: disable=no-self-use
-        await table_create_all()
+        await table_create_all(self.pool)
 
     def add_json_api_routes(self):
         """Add JSON API routes to the web application."""
@@ -125,11 +127,13 @@ class Application:
             web.get(path, self.get_related_resource),
         ])
 
-    def add_event_socket(self):
+    def add_event_socket_route(self):
         """Add event socket."""
 
-        path = '/event-socket'
-        self.app.add_routes([web.get(path, self.get_event_socket)])
+        path = '/event-socket/'
+        self.app.add_routes([
+            web.get(path, self.get_event_socket),
+        ])
 
     async def get_collection(self, request):
         """Entry point for GET /{collection} requests.
@@ -327,3 +331,10 @@ class Application:
         print('websocket connection closed')
         self.ws_list.remove(ws)
         return ws
+
+    async def broadcast(self, event):
+        """Broadcasts an event on all event sockets."""
+
+        stream_event = event.stream_event()
+        for ws in self.ws_list:  # pylint: disable=invalid-name
+            await ws.send_json(stream_event)
