@@ -77,9 +77,8 @@ class ResourceNotFoundMalformedIdError(Error):
 
     status = 404
 
-    def __init__(self, path, about=None):
+    def __init__(self, path):
         self.path = path
-        self.about = about
 
     def to_error(self):
         return {
@@ -99,9 +98,8 @@ class QueryParameterUnsupportedError(Error):
 
     status = 400
 
-    def __init__(self, parameter, about=None):
+    def __init__(self, parameter):
         self.parameter = parameter
-        self.about = about
 
     def to_error(self):
         return {
