@@ -41,6 +41,7 @@ from ajsonapi.errors import (
     ResourceNotFoundError,
     SortInvalidFieldError,
 )
+from ajsonapi.events import CreateEvent
 from ajsonapi.exceptions import ErrorsException, NonexistentRelationshipIdError
 from ajsonapi.logging import log
 from ajsonapi.query import parse_fields, parse_page, query_has_parameter
@@ -221,6 +222,8 @@ class Collection(Resource):
                                               document.attributes,
                                               document.relationships, query)
         await env.run()
+        event = CreateEvent(document.data)
+        await event.broadcast()
         return no_data_response()
 
     async def post_without_id(self, document, query):
@@ -235,6 +238,8 @@ class Collection(Resource):
         document.data['id'] = id_name
         path = f'{self.path()}/{id_name}'
         document.data['links'] = {'self': path}
+        event = CreateEvent(document.data)
+        await event.broadcast()
         return document_response({'data': document.data},
                                  status=201,
                                  headers={'Location': path})
